@@ -23,7 +23,6 @@ from .QLineNumberArea import QLineNumberArea
 from .QStyleSyntaxHighlighter import QStyleSyntaxHighlighter
 from .QSyntaxStyle import QSyntaxStyle
 
-
 PARENTHESES = [
     ("(", ")"),
     ("{", "}"),
@@ -32,7 +31,7 @@ PARENTHESES = [
     ("'", "'"),
 ]
 
-DEFAULT_FONT_POINT_SIZE: int = 14
+DEFAULT_FONT_POINT_SIZE: int | None = None
 DEFAULT_TAB_WIDTH: int = 4
 
 
@@ -53,6 +52,7 @@ class QCodeEditor(QTextEdit):
         self._tabReplace: str = " " * DEFAULT_TAB_WIDTH
         self._defaultIndent: int = self.tabReplaceSize()
 
+        # noinspection PyArgumentList
         _font = QFontDatabase.systemFont(QFontDatabase.FixedFont)
         self.setFont(_font)
 
@@ -102,34 +102,23 @@ class QCodeEditor(QTextEdit):
     def fontSize(self) -> int:
         return self.font().pointSize()
 
-    def setHighlighter(self, highlighter: QStyleSyntaxHighlighter):
+    def setHighlighter(self, highlighter: QStyleSyntaxHighlighter | None):
         if self._highlighter is not None:
             self._highlighter.setSyntaxStyle(None)
-            self._highlighter.deleteLater()
-            self._highlighter = None
+            self._highlighter.setDocument(None)
 
         self._highlighter = highlighter
         if self._highlighter:
             self._highlighter.setSyntaxStyle(self._syntaxStyle)
             self._highlighter.setDocument(self.document())
 
-            if self._highlighter.parent() is None:
-                highlighter.setParent(self)
-
     def setSyntaxStyle(self, syntaxStyle: QSyntaxStyle):
         assert syntaxStyle is not None
-        if syntaxStyle != QSyntaxStyle.defaultStyle():
-            self._syntaxStyle.clear()
-            self._syntaxStyle.deleteLater()
-            self._syntaxStyle = None
-
         self._syntaxStyle = syntaxStyle
         # self.m_framedAttribute.setSyntaxStyle(syntaxStyle)
         self._lineNumberArea.setSyntaxStyle(syntaxStyle)
         if self._highlighter:
             self._highlighter.setSyntaxStyle(syntaxStyle)
-            if self._syntaxStyle.parent() is None:
-                self._syntaxStyle.setParent(self)
         self._updateStyle()
 
     def setAutoParentheses(self, enable: bool):
@@ -163,8 +152,6 @@ class QCodeEditor(QTextEdit):
                 popup.hide()
             # noinspection PyUnresolvedReferences
             self._completer.activated.disconnect(self._insertCompletion)
-            self._completer.deleteLater()
-            self._completer = None
 
         self._completer = completer
         if not self._completer:
@@ -174,8 +161,6 @@ class QCodeEditor(QTextEdit):
         self._completer.setCompletionMode(QCompleter.CompletionMode.PopupCompletion)
         # noinspection PyUnresolvedReferences
         self._completer.activated.connect(self._insertCompletion)
-        if self._completer.parent() is None:
-            completer.setParent(self)
 
     def completer(self) -> QCompleter | None:
         return self._completer
@@ -317,7 +302,8 @@ class QCodeEditor(QTextEdit):
         pass
 
     def _initFont(self):
-        self.setFontSize(DEFAULT_FONT_POINT_SIZE)
+        if DEFAULT_FONT_POINT_SIZE and DEFAULT_FONT_POINT_SIZE > 0:
+            self.setFontSize(DEFAULT_FONT_POINT_SIZE)
 
     def _performConnections(self):
         doc = self.document()
